==> xdome-0.3.2.tar.gz: xdome-0.3.2/strut_length/about.c <==
/* about.c Version 0.3.2. Display GNU General Public License */
/* Copyright (C) 2004-2005  dondalah@ripco.com (Dondalah) */

/* Xdome is free software; you can redistribute it and/or */
/* modify it under the terms of the GNU General Public License */
/* as published by the Free Software Foundation; either version 2 */
/* of the License, or (at your option) any later version. */

/* Xdome is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program; if not, write to: */

/*       Free Software Foundation, Inc. */
/*       51 Franklin St, Fifth Floor    */
/*       Boston, MA  02110-1301, USA   */

/*									*/
/*      ABOUT: Display the GNU General Public License                   */
/*									*/

#include "strlen.h"

void about(void)
   {
   printf("xdome Version 0.3.2. "
      "Geodesic Dome for X Windows\n");
   printf("Copyright (C) 2004-2005  "
      "dondalah@ripco.com (Dondalah)\n");
   printf("Xdome is free software; "
      "you can redistribute it and/or\n");
   printf("modify it under the terms of "
      "the GNU General Public License\n");
   printf("as published by the Free Software "
      "Foundation; either version 2\n");
   printf("of the License, or (at your "
      "option) any later version.\n\n");

   printf("Xdome is distributed in "
      "the hope that it will be useful,\n");
   printf("but WITHOUT ANY WARRANTY; without "
      "even the implied warranty of\n");
   printf("MERCHANTABILITY or FITNESS FOR A "
      "PARTICULAR PURPOSE.  See the\n");
   printf("GNU General Public License "
      "for more details.\n\n");
   printf("You should have received a copy "
      "of the GNU General Public License\n");
   printf("along with this program; "
      "if not, write to:\n\n");
   printf("      Free Software Foundation, Inc.\n");
   printf("      51 Franklin St, Fifth Floor\n");
   printf("      Boston, MA  02110-1301, USA\n\n");
   printf("\nThe latest source code for xdome is "
      "available at:\n");
   printf("http://www.ibiblio.org/pub/linux"
      "/apps/graphics/visualization\n\n");
   } /* about */

==> xdome-0.4.0.tar.gz: xdome-0.4.0/strut_length/about.c <==
/* about.c Version 0.4.0. Display GNU General Public License */
/* Copyright (C) 2004-2010  dondalah721@yahoo.com (Dondalah) */

/* Xdome is free software; you can redistribute it and/or */
/* modify it under the terms of the GNU General Public License */
/* as published by the Free Software Foundation; either version 2 */
/* of the License, or (at your option) any later version. */

/* Xdome is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/* GNU General Public License for more details. */

/* You should have received a copy of the GNU General Public License */
/* along with this program; if not, write to: */

/*       Free Software Foundation, Inc. */
/*       51 Franklin St, Fifth Floor    */
/*       Boston, MA  02110-1301, USA   */

/*									*/
/*      ABOUT: Display the GNU General Public License                   */
/*									*/

#include "strlen.h"

void about(void)
   {
   printf("xdome Version 0.4.0. "
      "Geodesic Dome for X Windows\n");
   printf("Copyright (C) 2004-2010  "
      "dondalah721@yahoo.com (Dondalah)\n");
   printf("Xdome is free software; "
      "you can redistribute it and/or\n");
   printf("modify it under the terms of "
      "the GNU General Public License\n");
   printf("as published by the Free Software "
      "Foundation; either version 2\n");
   printf("of the License, or (at your "
      "option) any later version.\n\n");

   printf("Xdome is distributed in "
      "the hope that it will be useful,\n");
   printf("but WITHOUT ANY WARRANTY; without "
      "even the implied warranty of\n");
   printf("MERCHANTABILITY or FITNESS FOR A "
      "PARTICULAR PURPOSE.  See the\n");
   printf("GNU General Public License "
      "for more details.\n\n");
   printf("You should have received a copy "
      "of the GNU General Public License\n");
   printf("along with this program; "
      "if not, write to:\n\n");
   printf("      Free Software Foundation, Inc.\n");
   printf("      51 Franklin St, Fifth Floor\n");
   printf("      Boston, MA  02110-1301, USA\n\n");
   printf("\nThe latest source code for xdome is "
      "available at:\n");
   printf("http://www.ibiblio.org/pub/linux"
      "/apps/graphics/visualization\n\n");
   } /* about */
